package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````,!8``#0```!HD0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````](D`
M`/2)```%`````!````$```#(C0``R)T``,B=``!\`@``J`(```8`````$```
M`@```-"-``#0G0``T)T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,B-``#(G0``R)T``#@"```X`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`-D>"VV&9-EH$N9$R
M*'D'=UN:DD81````30````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A-````3@```%(```!7````6````&````!A````8@``````
M``!D````90````````!F````9P```&H```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````>!``````
M```#``@```````"@`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```/T!`````````````!$```"&`0``
M```````````2````%P``````````````$@```-8!`````````````!(````?
M```````````````2````)@``````````````$@````H"`````````````!(`
M``#B`0`````````````2````+P``````````````(````!0#````````````
M`"$```!'```````````````2````30``````````````$@```%0`````````
M`````!(```#3`@`````````````2````Z0(`````````````$@```%L`````
M`````````!(````E`@`````````````2````8@``````````````$@```*L"
M`````````````!(```!I```````````````2````<0``````````````$@``
M`,P"`````````````!(```!Y```````````````2````E`(`````````````
M$@```($``````````````!(```"*```````````````@````X@(`````````
M````$@```*8``````````````!(```"K```````````````2````L@``````
M````````$@```*,!`````````````!8```"R`@`````````````2````4@(`
M````````````$@```+L``````````````!(```!$`@`````````````2````
M6`,`````````````$@```+T"`````````````!$````3`P`````````````1
M````=@(`````````````$@`````#`````````````!(````5`P``````````
M```1````P@``````````````$@```,L``````````````!$```"4`0``````
M```````2````W0``````````````(@```.P``````````````"`````"`0``
M```````````2````LP``````````````$@```&("`````````````!(````'
M`0`````````````@````GP(`````````````$@```"$!`````````````!(`
M``#'`0`````````````2````)@$`````````````$@```(0"````````````
M`!(````L`0`````````````2````M@$`````````````$@```#H!````````
M`````!(```!+`0`````````````2````(`(`````````````$@```#$"````
M`````````!(```!1`0`````````````2````:P(`````````````$@```-L"
M`````````````!(```#X`@`````````````2````8`$`````````````$@``
M`!L"`````````````!(```!G`0`````````````2````;@$`````````````
M$@```!(#`````````````"$```!_`0`````````````2````8`0``'"@````
M````$``3``T#``!H$P``R`(``!(`"@#W`0```$@```0````2``L`F@,``#0N
M``"P!@``$@`*`'`$``#P-P``0`$``!(`"@!W`P``#"````0````2``H`%`0`
M`'@0```$````$@`(`+T#``#D-```#`,``!(`"@`:!```1*`````````0`!,`
M2`0``!`@``"D`@``$@`*`/4#``!$H````````!``$P"(`P``S"P``&@!```2
M``H`IP,``$0>``!8````$@`*`*\#``#4*0``H````!(`"@#3`P``*$4``(@!
M```2``H`Z`,``+0B```P````$@`*``$$``!PH````````!``$P`)!```="H`
M`'`````2``H`:P0``'"@````````$``3`#T#``!4%@``:````!(`"@`H!```
MY"(``*P!```2``H`W@,``$"@```$````$0`2`$$$``!$H````````!``$@#Z
M`P``,!8````````2``H`$00``+Q$``!L````$@`*`$8#``"H+```)````!(`
M"@!A`P``G!X``'`!```2``H`500``+!&``!0`0``$@`*`%\$``!PH```````
M`!``$P`T!```D"0``$0%```2``H``&]P96YD:7(`;65M8VUP`'-T9&5R<@!R
M96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF
M;P!L<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S
M=')N8VUP`'-T<G)C:'(`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`&]P96X`<W1R<W1R`'9F<')I;G1F`'-T<F-H<@!R96%D;&EN:P!?
M7W-T86-K7V-H:U]G=6%R9`!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R
M86UE7VEN9F\`97AI=`!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`
M<FUD:7(`7U]S=&%T7W1I;64V-`!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`%]?
M;'-T871?=&EM938T`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G
M971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT
M7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!03%]M96UO<GE?=W)A<`!S=')C<'D`<F5A9&1I<@!S=')T;VL`<W1R9'5P
M`'!T:')E861?871F;W)K`'-P<FEN=&8`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UA<FUH9BYS;RXQ`%]S=&%R
M=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A
M<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?
M7V)S<U]S=&%R=`!?7V5N9%]?`'!A<E]D:64`<VAA7VEN:70`7U]B<W-?<W1A
M<G1?7P!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD
M<')O9P!S:&%?9FEN86P`7U]B<W-?96YD7U\`7V5N9`!P87)?8VQE86YU<``O
M=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210```,B=```7````S)T``!<`
M``"\GP``%P```,B?```7````U)\``!<`````H```%P```!"@```7````%*``
M`!<````<H```%P```""@```7````)*```!<````HH```%P```"R@```7````
M-*```!<````XH```%P```$"@```7````P)\``!4%``#$GP``%08``,R?```5
M#@``T)\``!4?``#8GP``$R0``-R?```5*@``X)\``!4N``#DGP``%3```.B?
M```5,@``[)\``!4S``#PGP``%3<``/2?```5/```^)\``!4^``#\GP``%4(`
M`,R>```6`P``T)X``!8$``#4G@``%@<``-B>```6"```W)X``!8)``#@G@``
M%@H``.2>```6"P``Z)X``!8,``#LG@``%@T``/">```6#@``])X``!80``#X
MG@``%A$``/R>```6$@```)\``!83```$GP``%A0```B?```6%0``#)\``!86
M```0GP``%A<``!2?```6&```&)\``!89```<GP``%AH``""?```6&P``))\`
M`!8<```HGP``%AT``"R?```6'@``,)\``!8@```TGP``%B$``#B?```6(@``
M/)\``!8C``!`GP``%B4``$2?```6)@``2)\``!8G``!,GP``%B@``%"?```6
M*0``5)\``!8L``!8GP``%BT``%R?```6+P``8)\``!8Q``!DGP``%C(``&B?
M```6,P``;)\``!8T``!PGP``%C4``'2?```6-@``>)\``!8X``!\GP``%CD`
M`("?```6.@``A)\``!8[``"(GP``%CT``(R?```6/P``D)\``!9```"4GP``
M%D$``)B?```60P``G)\``!9$``"@GP``%D4``*2?```61@``J)\``!9'``"L
MGP``%D@``+"?```620``M)\``!9*``"XGP``%DP```%`+>D!0+WH'O\OX03@
M+>4$X)_E#N"/X`CPON4LC@```,:/X@C*C.(L_KSE`,:/X@C*C.(D_KSE`,:/
MX@C*C.(<_KSE`,:/X@C*C.(4_KSE`,:/X@C*C.(,_KSE`,:/X@C*C.($_KSE
M`,:/X@C*C.+\_;SE`,:/X@C*C.+T_;SE`,:/X@C*C.+L_;SE`,:/X@C*C.+D
M_;SE`,:/X@C*C.+<_;SE`,:/X@C*C.+4_;SE`,:/X@C*C.+,_;SE`,:/X@C*
MC.+$_;SE`,:/X@C*C.*\_;SE`,:/X@C*C.*T_;SE`,:/X@C*C.*L_;SE`,:/
MX@C*C.*D_;SE`,:/X@C*C.*<_;SE`,:/X@C*C.*4_;SE`,:/X@C*C.*,_;SE
M`,:/X@C*C.*$_;SE`,:/X@C*C.)\_;SE`,:/X@C*C.)T_;SE`,:/X@C*C.)L
M_;SE`,:/X@C*C.)D_;SE`,:/X@C*C.)<_;SE`,:/X@C*C.)4_;SE`,:/X@C*
MC.),_;SE`,:/X@C*C.)$_;SE`,:/X@C*C.(\_;SE`,:/X@C*C.(T_;SE`,:/
MX@C*C.(L_;SE`,:/X@C*C.(D_;SE`,:/X@C*C.(<_;SE`,:/X@C*C.(4_;SE
M`,:/X@C*C.(,_;SE`,:/X@C*C.($_;SE`,:/X@C*C.+\_+SE`,:/X@C*C.+T
M_+SE`,:/X@C*C.+L_+SE`,:/X@C*C.+D_+SE`,:/X@C*C.+<_+SE`,:/X@C*
MC.+4_+SE`,:/X@C*C.+,_+SE`,:/X@C*C.+$_+SE`,:/X@C*C.*\_+SE`,:/
MX@C*C.*T_+SE`,:/X@C*C.*L_+SE`,:/X@C*C.*D_+SE`,:/X@C*C.*<_+SE
M`,:/X@C*C.*4_+SE`,:/X@C*C.*,_+SE`,:/X@C*C.*$_+SE`,:/X@C*C.)\
M_+SE`,:/X@C*C.)T_+SE`,:/X@C*C.)L_+SE`,:/X@C*C.)D_+SE`,:/X@C*
MC.)<_+SE`,:/X@C*C.)4_+SE`<J@XW!`+>D,P$W@R`^,Y5C"G^4HT$WB5#*?
MY1P`C>48$(WE%""-Y0S`C^`#,)SG&!"-XA0@C>(<`(WB-%*?Y0`PD^4D,(WE
M`#"@XZ;__^LD(I_E!5"/X`(@E><<,I_E#""-Y0,PE><"$*#A`P"@X1`PC>57
M___K!#*?Y0,PE><`0-/E``!4XT\```IP+QWN\#&?Y1P`G>4#,)_G`T"`X@,@
MDN<$`(#BUC/2Y0<!<.,#,(/CUC/"Y6```(H``:#AF___ZP`PH.&\(9_E&!"=
MY0(@C^``8)+EL,&?Y;!1G^6PX9_E'""=Y0``D>4,P(_@!5"/X`[@C^`!`%+C
M84"#Z`0PC.54``#:!`!!X@S`@^("`8#@!."QY0$`4.$$X*SE^___&@/`@N(`
MX*#C:%&?Y6@1G^4%4(_@#`"5Y00@H.$`X(WE`1"/X`SA@^<\___K``!0XRD`
M``I$49_E(&"-X@50C^`,`)7E5O__ZP!`H.$P`9_E!A"@X0``C^#5``#K``!0
MXR````H<,9_E`S"/X`P`D^6-___KZO[_ZPPAG^7,,)_E`B"/X`,PDN<`()/E
M)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB<("]Z"[__^O<()_E``!0XP(@C^`,
M`(+E'P``"EC__^MP+QWNQ#"?Y0,PG^<#,)+GKD;#Y:/__^H,`)7E1___Z]+_
M_^H(`)7E``!0XP$```J:"`#KV?__ZI0`G^4&$*#A``"/X*D``.L``%#C"`"%
MY=+__PKU___J>#"?Y7@`G^4#,)7G``"/X`,0H.$,,(WES/[_ZP3`H..P___J
M`0"@XRC__^M=___K*(L``"0!``#\B@``/`$``#@!```$`0``T(L```",```$
MC```3#<``$PW``"\BP``Y`@``)"+``!H-```9(L``*R)```8BP``>(H``%0S
M```<`0``,#4```"PH.,`X*#C$!"?Y0$0C^`-`*#A#\#`XPS0H.$```#KC(<`
M``3@+>4`X*#C`""@X400G^5$`)_E`1"/X```D><4T$WB.#"?Y0@`C>4#,)'G
M,,"?Y0PPC>4$X(WE#!"1YP`PH.$`$(WE#`"=Y000DN3E_O_K%-"-X@3PG>10
MB```%`$``/P````(`0``+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_
M+P$8()_E`C"3YP``4^,>_R\!$_\OX7B)``!TB0``Y(<``!`!```X`)_E.#"?
MY0``C^`#,(_@`#!#X*,?H.%#$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G
M``!3XQ[_+P$3_R_A-(D``#")``"4AP``,`$```'*H.,00"WI#,!-X/@/C.5D
M,)_E9$"?Y0,PC^``,-/E!$"/X```4^,0@+T84#"?Y0,PE.<``%/C`@``"D0P
MG^4#`)_GL?[_Z\?__^LX,)_E`S"4YP``4^,"```*+`"?Y0``C^!2_O_K`2"@
MXR`PG^4#,(_@`"##Y1"`O>C4B```2(<``"@!``!HB```#`$``#AR``!\B```
M0#"?Y4`@G^4#,(_@`C"3YP``4^,*```*`<J@XQ!`+>D,P$W@^`^,Y2`0G^4@
M`)_E`1"/X```C^"1_O_K$$"]Z+3__^JS___JR(8``"P!```HB```S'$```'*
MH./P1RWI#,!-X.`/C.7(,)_E`(!0X@,PC^`K```*O""?Y0(PD^<`D)/E``!9
MXR@```H`4-CE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"9Y0``5.,,```*
M"6"@X04@H.$($*#A!`"@X37^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4`
M`%3C\___&@0`H.'PA[WH"%"@X0$P]>4``%/C/0!3$_O__QH(4$7@YO__Z@E@
M1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'O>@(0*#A[?__Z@E`H.'K___J8(8`
M`"`!```!RJ#C$$`MZ0S`3>!8#XSEC""?Y8PPG^4"((_@H-!-X@,PDN<-$*#A
M`#"3Y9PPC>4`,*#C`$"@X67^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!
M"5,3"@``"D@@G^5`,)_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C!P``&J#0
MC>(0@+WH`A"@XP0`H.'%_?_K$`]OX:`"H.'N___J8/[_ZWB%```D`0``+(4`
M``'*H./P0"WI#,!-X$@/C.54(9_E5#&?Y0(@C^`#,)+GI-!-X@!04.(`,)/E
MG#"-Y0`PH.,"```*`##5Y0``4^,*```:*"&?Y2`QG^4"((_@`S"2YP`@D^6<
M,)WE`B`SX``PH.,_```:I-"-XO"`O>B2_?_K`$!0XO'__PH$`*#AM?W_ZP``
M4.,H```*$S#0Y1-@@.(N`%/C`@``&@$PUN4``%/C]/__"A,PT.4N`%/C(P``
M"@4`H.$K_O_K`'"@X08`H.$H_O_K``"'X`(`@.*P_?_K!C"@X0!@H.&4$)_E
M!2"@X0$0C^`6_O_K!@"@X0T0H.'^_?_K`0!PXP8`H.$#```*$#"=Y0\Z`^(!
M"5/C$@``"IS]_^L&`*#A_?W_ZP0`H.&,_?_K``!0X];__QH$`*#AJ?W_ZP4`
MH.'I_?_KO___Z@$PUN4N`%/CV/__&@(PUN4``%/CQ___"M3__^JF___KZ___
MZ@+^_^O(A```)`$``)2$``#8+0```<J@X_!'+>D,P$W@V`^,Y0%`H.$0(I_E
M$#*?Y0(@C^`#,)+G"-!-X@`PD^4$,(WE`#"@XP`PT>4`4*#A/0!3XP%`@0($
M`*#AZ/W_ZPT0H.$`8*#A!0"@X2/__^O0<9_E`)!0X@=PC^!````*W_W_ZP``
M5N$W``":N#&?Y0"`G>4#<)?G"(&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``
M"@4PH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"7Y53]_^L``%#C
M"`"&YQ4```H%`*#A`#"7Y0@0D^<!,-#D/0!3XP``4Q,`,,'E!@``"@$@@>(!
M,-#D`A"@X3T`4^,``%,3`3#"Y/G__QH],*#C`2"@X0`PP>4!,-3D``!3XP$P
MXN7[__\:""&?Y?@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,U```:"-"-
MXO"'O>@!D$GB`3#4Y```4^,!,.GE^___&N[__^K`,)_E`W"7YP"`E^4`,)CE
M``!3XR0```H(,*#A!""SY0D0H.$``%+C`9")XOK__QH#$('B`1&@X9`PG^4#
M,(_@`""3Y0``4N,/```:`2"@XP$`H.$`((/E$_W_ZP"@4.+5__\*"!"@X0F!
MH.$((*#A$/W_ZP"@A^4`,*#C`)"-Y0&0B>(),8KGHO__Z@@`H.'8_/_K``!0
MXP"@H.$``(?EQ?__"@F!H.'R___J`Y"@X0@0H./?___J<_W_ZTB#```D`0``
M`(,``"`!```P@@``6(,```'*H.,00"WI#,!-X.@/C.5P3QWN;!"?Y6PPG^4!
M$(_@`S"1YQ#03>)@`)_E##"-Y0,@H.$``)_G5#"?Y500G^4``)3G`S"/X`$0
MC^!'_?_K`,"@XT``G^5`,)_E``"?YSP@G^4\$)_E`S"/X```E.<"((_@"!"-
MZ`$0C^"T_/_K$-"-XA"`O>@$@0``-`$```2"``!H:P``O"H``-R!``"@+0``
MU!8``*@J```\$)_E/#"?Y0$0C^`#,)'G<,\=[@,@H.$(T$WB*`"?Y00PC>4`
M`)_G(#"?Y2`0G^4``)SG`S"/X`$0C^`(T(WB'_W_ZFR````T`0``:($``,QJ
M```@*@```<J@XW!`+>D,P$W@``",Y0'*3.(``(SE*``,Y30AG^4T,9_E`MI-
MXAC03>("((_@`S"2YP(:C>(4$('B`#"3Y0`P@>4`,*#CC/S_ZPS!G^4,09_E
M#"&?Y0S`C^`,8(WB`#"@X000H.$&`*#A`B"/X`#`C>5R_/_K`3"`X@0`4^$P
M``"*`0!PXR\```H!6HWB$%"%X@$JH.,%$*#A!@"@X<'\_^L`0%#B)P``N@$`
MA.*'_/_K`#!0XB,```H%`%/A`@``*@0@@^`"`%7A'0``.@4`4^$8``"*A""?
MY0(`5.$8``"*!""@X0,`H.$%$*#AYOS_ZP`@H.,`,*#A!"#`YV00G^50()_E
M`1"/X`(*C>("()'G%`"`X@`0DN4`()#E`1`RX``@H.,)```:`P"@X0+:C>(8
MT(WB<("]Z`0@A>`"`%/AX___*O``\.<`,*#CZO__ZM;\_^OP?P``)`$``.@I
M```!$```R"D``!1_``"B___J`<J@X_!/+>D,P$W@``",Y=``#.58PI_E6"*?
MY4+=3>(LT$WB#,"/X`!0H.%(`I_E`B"<YT(]C>((<(WB`6"@X0``C^`'$*#A
M)#"#X@`@DN4`((/E`""@X_3]_^LO$*#C`$"@X04`H.%C_/_K``!0XQ(```H$
M`I_E!1"@X0``C^"O_O_K!0"@X?0AG^7D,9_E`B"/X$(=C>(#,)+G)!"!X@`@
MD^4`,)'E`B`SX``PH.-M```:0MV-XBS0C>+PC[WH!@"@X3K\_^NX$9_E`1"/
MX(O\_^L`H%#BY?__"@`PVN6D@9_EJ)"-X@``4^,(@(_@!&!)XC\```H``%3C
M!```"@H0H.$$`*#A`OS_ZP``4.,O```*"@"@X87\_^L!,$#B`S"*X`,`6N$`
M(*#A`+"@X0`0H#,`((HP`3"*,@,``#H(``#J`@!3X0`0PN4"```*`<!RY2\`
M7./Y__\*"@"@X7/\_^L`L*#A!0"@X7#\_^L+`(#@`0"`X@$*4..\__\J",&?
MY0HPH.$,P(_@"""@X0$:H.,&`*#A!%"-Y0#`C>7*^__K`0"`X@$*4.,O``"*
M!Q"@X08`H.$__/_K``!0XP,``!J0,!GE#SH#X@()4^,5```*N!"?Y0``H.,!
M$(_@1_S_ZP"@4.*A__\*`##:Y0``4^.___\:``!4XQ8```H`,-3E+@!3XP,`
M``J$H)_E`;"@XPJ@C^#2___J`3#4Y0``4^/J__\*]___Z@$0H.,&`*#AHOO_
MZP``4./D__\:5`"?Y080H.$``(_@//[_ZP8`H.'6^__KBO__ZCR@G^4!L*#C
M"J"/X+[__^HS_/_K\`#PYX1^```D`0``E"@``&0H```8?@``)"@```@H``!T
M)P``%"<``+PF``"8)@``;"8```'*H.,00"WI#,!-X/@/C.4O$*#C`$"@X;/[
M_^L``%#C`4"`$@0`H.$00+WHM_O_Z@'*H.,P0"WI#,!-X```C.48``SE="&?
MY70QG^4!VDWB`B"/X`S03>(!&HWB`S"2YP!04.($$('B`#"3Y0`P@>4`,*#C
M,```"@`PU>4``%/C+0``"@'\_^L!`(#B`0I0XSH``(H$0(WB!1"@X00`H.&.
M^__K!`"@X?C[_^L!`$#B``"$X`0`4.$'``":`""@XP(``.H$`%#A`2#`Y0(`
M``H!,%#D+P!3X_G__PHO$*#C!`"@X8#[_^L``%#C)0``"@0`4.$`,*"#`##`
MA00`H.&"^__KO""?Y;0PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@
M`#"@XR(``!H!VHWB#-"-XC"`O>B(()_E?#"?Y0(@C^`!&HWB`S"2YP00@>(`
M()/E`#"1Y0(@,^``,*#C%```&F``G^4``(_@`=J-X@S0C>(P0+WH8_O_Z@``
MH./>___J1""?Y3`PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@
MXR``GP4``(\`[/__"K;[_^NT>P``)`$``/AZ``#`>@``P"0``'1Z``!X)```
M`<J@XW!`+>D,P$W@Z`^,Y<0DG^7$-)_E`B"/X,!4G^4#,)+GO&2?Y0C03>(%
M4(_@`#"3Y00PC>4`,*#C!F"/X`U`H.$$$*#A!@"@X=?\_^L``%#C#@``"HPT
MG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2
MXP0@@^3[__\:Z___ZE1DG^4&8(_@!!"@X08`H.'!_/_K``!0XPX```HT-)_E
M`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$
M((/D^___&NO__^H`9)_E!F"/X`00H.$&`*#AJ_S_ZP``4.,.```*W#.?Y0`0
MG>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#
MY/O__QKK___JK&.?Y09@C^`$$*#A!@"@X97\_^L``%#C#@``"H0SG^4`$)WE
M`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[
M__\:Z___ZEACG^4&8(_@!!"@X08`H.%__/_K``!0XPX```HL,Y_E`!"=Y0,P
ME><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___
M&NO__^H$8Y_E!F"/X`00H.$&`*#A:?S_ZP``4.,.```*U#*?Y0`0G>4#,)7G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___JL&*?Y09@C^`$$*#A!@"@X5/\_^L``%#C#@``"GPRG^4`$)WE`S"5YP`@
MD^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___
MZEQBG^4&8(_@!!"@X08`H.$]_/_K``!0XPX```HD,I_E`!"=Y0,PE><`()/E
M`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H(
M8I_E!F"/X`00H.$&`*#A)_S_ZP``4.,.```*S#&?Y0`0G>4#,)7G`""3Y0$Q
M@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___JM&&?
MY09@C^`$$*#A!@"@X1'\_^L``%#C#@``"G0QG^4`$)WE`S"5YP`@D^4!,8+@
M!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZF!AG^4&
M8(_@!!"@X08`H.'[^__K``!0XPX```H<,9_E`!"=Y0,PE><`()/E`3&"X`0`
MD^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H,`9_E!!"@
MX0``C^#F^__K`!!0X@(```KX`)_E``"/X*;\_^OP`)_E!!"@X0``C^#=^__K
M`!!0X@(```K<`)_E``"/X)W\_^O4`)_E!!"@X0``C^#4^__K`!!0XA(```K`
M`)_E``"/X)3\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQ``
M`!J8$)_EF`"?Y0$0C^```(_@"-"-XG!`O>B$_/_JA`"?Y000H.$``(_@N_O_
MZP`04.+I__\*<`"?Y0``C^![_/_KY?__ZGCZ_^L0>@``)`$``/QY``!$)```
M(`$``/0C``"D(P``6",```@C``#`(@``!"(``!PB``#0(0``A"$``+`@``#<
M(```L"```,P@``#,(```R"```.P?``"P=0``I"````@@``!T(```^!\```'*
MH.,$X"WE#,!-X/`/C.5X()_E>#"?Y0(@C^!T`)_E#-!-X@,PDN<-$*#A``"/
MX``PD^4$,(WE`#"@XXK[_^L``%#C!0``"@``T.4``%#C,`!0$P$`H`,``*`3
M`0`@XC0@G^4H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C`0``&@S0C>($
M\)WD.OK_Z\QT```D`0``5!\``'QT```!RJ#C#P`MZ03@+>4,P$W@\`^,Y40@
MG^5$,)_E`B"/X`,PDN<,T$WB`#"3Y00PC>4`,*#C+#"?Y2P`G^44((WB`S"/
MX``@C>4`,)/G$!"=Y0``D^7&^?_K_P"@X^CY_^LH=```)`$```1T`````0``
M`,"@X_!'+>D!Z*#C#,!-X`[@3.`!RDSB``",Y0X`7.'[__\:.``.Y0(0H.-T
MX9_E=,&?Y0'83>(8T$WB#N"/X`S`GN<!2(WB`""@XP`PH.,`P)SE%,"$Y0#`
MH.,`$(WE`("@X7#Y_^L!8%#B`'#!XL<OH.''/R;@`C!3X',P_^8","/@`C!3
MX`(@PN`#8%;@`G#'X```5^,40(3B-P``N@B1G^4,4(WB`!"@XP8@H.$',*#A
M"`"@X0`0C>5:^?_K`0!QXP$`<`,R```*"2"@X040H.$(`*#AN?G_ZP$`<.,I
M```*!P!0XQ\``)H(`$#B`$"5X!P``"JTH)_E"J"/X`(``.H!0$3B!0!4X18`
M`#H((*#C"A"@X00`H.$G^?_K``!0X_;__QH%0$3@!@"4X,0?I^!\()_E;#"?
MY0(@C^`!R(WB`S"2YQ3`C.(`()/E`#"<Y0(@,^``,*#C$```&@'8C>(8T(WB
M\(>]Z`%H5N(`<,?B`0!WXP$(=@/)__\:``#@XP`0H.'I___J*`"?Y0``C^!]
M___K(`"?Y0``C^!Z___KL/G_ZYAS```D`0``"``!`!QT``"8<@``<!T``%0=
M```!RJ#C$$`MZ0S`3>#X#XSEI_G_ZUCY_^L``%#C``"0%1"`O>@!RJ#C\$`M
MZ0S`3>#8#XSE+"&?Y2QAG^4L,9_E`B"/X!303>(#,)+G!F"/X`!0H.$&`*#A
M"!"-X@`PD^4,,(WE`#"@X\KZ_^L`0%#B`@``"@`PU.4``%/C#@``&NP@G^7D
M,)_E`B"/X`,PDN<`()/E##"=Y0(@,^``,*#C+P``&@40H.'(`)_E``"/X!30
MC>+P0+WH>_O_Z@40H.$;^?_K``!0XPH```JH()_EF#"?Y0(@C^`#,)+G`""3
MY0PPG>4"(#/@`#"@XQP``!H4T(WB\("]Z`4`H.%F^?_K`'"@X00`H.%C^?_K
M``"'X`(`@.+K^/_K8#"?Y6`0G^4%(*#A`S"/X`$0C^``0(WE`$"@X4_Y_^M(
M()_E+#"?Y0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XP00H`$&`*`!TO__"D_Y
M_^O0<0``_!P``"0!``"(<0``G!P``#QQ```T&P``-!L``-!P```!RJ#C\$\M
MZ0S`3>#`#HSE1]]-XLB@C>(*X*#A`!:?Y0#&G^4`)I_E`1"/X`(@D><,P(_@
M##",XAB0C.*P4(WB`""2Y10AC>4`(*#C`'"@X0<`D^@'`(7H#P"YZ`\`KN@#
M`)GH,,",XKQ`C>(#`([H!P"<Z`<`A.BP!9_E&&"-X@80H.$``(_@7_K_ZZ"%
MG^4`D%#B"("/X`(```H`,-GE``!3XPD!`!H>^?_KS_C_ZP``4.-R```*`)"0
MY0``6>-O```*"0"@X1#Y_^N``*#A`0"`XICX_^L`(-GE`$"@X0``4N,4`(WE
M"```"D2UG^4+L(_@!`"@X0L0H.'Z^/_K`2#YY0)`A.(``%+C^/__&B0%G^4`
M`(_@`@``Z@0`NN4``%#C#0``"@80H.$V^O_K`$!0XOC__PH`,-3E``!3X_7_
M_PIJ^O_K``!0X_+__PH$`*#AC?C_ZP!`4.(,```:!$"5Y```5.,)```*`##4
MY0``4^/%```*!`"@X5SZ_^L``%#C\?__&@1`E>0``%3C]?__&@0`H.'<^/_K
M%)"=Y0!0H.$)`*#AV/C_ZP!0A>`!6X7B!%"%X@4`H.%>^/_K!)"-Y0"0H.%P
M-)_E<!2?Y0,PC^``,(WE:#2?Y00@H.$#,(_@`1"/X+_X_^L'':#C"0"@X:WX
M_^L!`'#C`P``&J?X_^L`P)#E$0!<XZ4``!H&$*#A"0"@X:KX_^L`0%#B+```
M"B`DG^4@%)_E`@"8YPDPH.$`()?E``"0Y0$0C^""^/_K`%"@XP0DG^78,Y_E
M`B"/X`,PDN<`()/E%#&=Y0(@,^``,*#CZ0``&@4`H.%'WXWB\(^]Z$3X_^L`
MD%#BA```&@0`E.0``%#C"0``"@80H.'<^?_K`#!0XOC__PH`,-/E``!3X_+_
M_QH$`)3D``!0X_7__QH-`*#C'OC_ZY"3G^53(*#C`$"@X0F0C^`4`(WEA/__
MZB@PG>4/.@/B`0E3X\[__QHPH)WEC?C_ZP``6N'*__\:*#"=Y8,[H.&C.Z#A
M!PU3X\7__QH%`*#A"?C_ZP!0H.$\`Y_E!A"@X0``C^"X^?_K`!!0XG4```H`
M`)?EJ/O_ZP"@4.)Q```*"@"@X7'X_^L#`%#C`("@X0P``)H$$Y_E!`!`X@``
MBN`!$(_@XO?_ZP``4.,%```:!`!8XY<```H(@(K@!3!8Y2\`4^.3```*U`*?
MY080H.$``(_@G/G_ZP``4.,#```*`##0Y3``4^,``%,3!```&@`0H.,*`*#A
M]_?_ZP!@4.)2```:G!*?Y9P"G^4!$(_@``"/X%'Z_^O"]__KC"*?Y8PRG^6,
M$I_E`B"/X(B"G^6(<I_EB&*?Y04`C>@#,(_@"2"@X04`H.$!$(_@-OC_ZPB`
MC^`'<(_@!F"/X`T``.H?^/_K`#"0Y1$`4^,.```:K/?_ZP#`H.$!0(3B"#"@
MX0D@H.$'$*#A!0"@X5``C>D`P(WE)/C_ZP<=H.,%`*#A$OC_ZP$`<./L__\*
M"0"@X1'X_^L,`I_E!1"@X0``C^`F^O_K!0"@X8+^_^MM___J`T"@X3[__^H<
M^/_K@`"@X0$`@.(*___JG"&?Y=@1G^4"`)CG"3"@X0`@E^4!$(_@`,"-Y0``
MD.7@]__K7/__ZG#^_^NT(9_E3#&?Y0(@C^`#,)+G`""3Y10QG>4"(#/@`#"@
MXT8``!H)`*#A1]^-XO!/O>BA]__J`*"7Y8O__^KF_?_K`(!1X@!PH.&H__^Z
M`*"@XPH@4.(`,,CB!@"@X0"@C>7@L(WB9_?_ZP8@H.,+$*#A!@"@X<GW_^L&
M`%#C,```&C@QG^7@()WE`P!2X9?__QJT(-OA*#&?Y0,`4N&3__\:,B!7X@`P
MR.(&`*#A`*"-Y>A`C>)3]__K*""@XP8`H.$$$*#AM??_ZR@`4.,<```:\""?
MY?`PG^7P$)_E`B"/X`0@C>4%`*#A"2"@X0!`C>4#,(_@`1"/X!"AS>7%]__K
MI/__Z@1PE^4``%?C:/__"@<`H.'(]__K`P!0XV3__YJL$)_E!`!`X@``A^`!
M$(_@.O?_ZP``4.,'H*`!7/__ZL#W_^N,`)_E``"/X(;]_^M<<```F'$``"0!
M```L&@``\&\``.0:``!8&@``&!H``/@9``#X&`````$``/`9```T;@```!D`
M`&`9```H&0``D!<``-`7``!0%P``A!D``-P6``"L&```R!8``+`8``!4&0``
M-!8``#07``"H:P```$-!0TA%``"\%P``%!4``-P6``"0%@``?!8```'*H./P
M0"WI#,!-X.`/C.6,(I_EC#*?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@XW!/
M'>X-8*#A;#*?Y6P"G^4#,)_G!A"@X0-0E.<``(_@9##5Y64PQ>6_^/_K``!0
MXP(```H`,-#E,0!3XV(```K-^__K.#*?Y0,PG^<#4)3G,!*?Y04`H.$#,*#C
M`2"@XP$0C^`@]__K`%!0X@P```H,()7E$#*?Y0`0DN4#,)_G""*?Y0,`E.<"
M((_@'/?_ZPPPE>4`$)/E"#"1Y0$%$^-:```:Z!&?Y0,PH.,!$)_G`2"@XP$`
ME.?8$9_E`1"/X`GW_^L`4%#B"P``"L@!G^4&$*#A``"/X)/X_^L`(%#B/0``
M"K0QG^4,$)7E`S"?YP`0D>4#`)3G`??_ZZ`QG^6@$9_E`S"?YP$@H.,#4)3G
M`1"/X`4`H.&E]O_KB"&?Y0`0H.$"((_@!0"@X?3V_^L`(*#C=#&?Y70!G^4#
M,)_G!A"@X0,PE.<``(_@92##Y77X_^M<09_E``!0XP1`C^`(`(3E$```"@<=
MH.,7]__K`3"`XA$`4.,!`%,3-```BC0AG^7L,)_E`B"/X`,PDN<`()/E!#"=
MY0(@,^``,*#C*@``&@S0C>+P@+WH!`"4Y=K]_^L``%#C"`"$Y>G__QKX`)_E
M``"/X(7V_^L!,-#E``!3XYW__PJ8___JZ?G_ZP!P4.(.```*U#"?Y0P@E>4#
M,)_G`!"2Y0,`E.<'(*#AO_;_ZP<`H.'S]O_KNO__ZK`PG^4#,)_G`P"4YXCV
M_^N?___JH""?Y:`PG^4"((_@#!"5Y0,PG^<$()+E`!"1Y0`@DN4#`)3GK?;_
MZZK__^KY]O_K>""?Y0`PH.%T`)_E`B"/X`8`DND``(_@`!"1Y5OV_^N\:0``
M)`$``*QJ```(%```=&H``)@5``!`:@``=!4``!!J``!(%0``"!,``-!I``"X
M:0``^!0``/P4``"`:0``B!(``.AI```<:```9!0``,QH``"H:```&&D``(AH
M``#D:```Y!,```'*H.,P0"WI#,!-X.@/C.40(9_E$#&?Y0(@C^`#,)+G#-!-
MX@`PD^4$,(WE`#"@XP!0H.&N^O_K+Q"@XP!`H.%:]O_K``!0XP%`@!($`*#A
M7_;_ZP!`H.'0`)_E#1"@X0``C^#Y]__K`#!0X@H```H`,-/E,`!3XP``4Q,!
M,*`#`#"@$P$P(^(``%7C`#"@`P$P`Q(``%/C"@``&I`@G^6$,)_E`B"/X`,P
MDN<`()/E!#"=Y0(@,^``,*#C&```&@S0C>(P@+WH`##5Y0``4^/Q__\*7!"?
MY00@H.,$`*#A`1"/X"OV_^L``%#CZO__&D0@G^4P,)_E`B"/X`,PDN<`()/E
M!#"=Y0(@,^``,*#C`P``&@4`H.$,T(WB,$"]Z##X_^J-]O_KL&8``"0!```$
M$0``)&8``$P1``#090```<J@X_!/+>D,P$W@D`Z,Y5@KG^58.Y_E`B"/X`,P
MDN=3WTWB`#"3Y40QC>4`,*#C#1"@X0!PH.$<((#B7`"`X@0PDN0S/[_F``!2
MX00PH>7Z__\:.`"=Y3S@G>5`,)WE!,"=Y0A0G>4(((WB0F^-X@```.H!4*#A
M`T"@X1PPDN4$$++E`3`CX``P(^`,,"/@XS^@X0(`5N$.`*#A!<"@X03@H.$X
M,(+E\?__&L0ZG^4,4)?E!!"=Y1!`E^4!$)?I`."7Y04@+.`#$('@!!"!X``@
M`N`%("+@"&"=Y>X=@>`"$('@8"$LX`-@AN`.(`+@!6"&X`P@(N!ND:#A!B""
MX`Q@G>5@@2G@`V"&X`&`".`,8(;@%+"=Y6"!*.#A+8+@$*"=Y0:`B.!A82G@
MXHV(X`)@!N`#L(O@8B&@X0FPB^`#H(K@"6`FX&&1(N!@H8K@")`)X`I@AN!A
MD2G@&*"=Y>AMAN`+D(G@:+$BX`.@BN`&L`O@YIV)X&&ABN!F$:#A`F`KX`I@
MAN`<H)WE:+$AX`.@BN`"((K@(*"=Y0FP"^`#H(K@Z6V&X&BABN!H@2O@:;$A
MX`*`B.`&L`O@YHV(X&8AH.$!8"O@"F"&X"2@G>5IL2+@`Z"*X`$0BN`HH)WE
M"+`+X`.@BN!IH8K@:9$KX.AMAN`!D(G@:!$BX`80`>`"$"'@"A"!X"R@G>7F
MG8G@`Z"*X&9AH.$"((K@,*"=Y6BQ)N`)L`O@`Z"*X&BABN!H@2O@Z1V!X`*`
MB.!I(2;@`2`"X`8@(N`*((+@-*"=Y>&-B.`#H(K@81&@X09@BN!IH2'@"*`*
MX#BPG>5IH2K@Z"V"X`:@BN!H82'@`["+X`)@!N!IL8O@`6`FX`M@AN`\L)WE
MXJV*X`.PB^!B(:#A`;"+X$`0G>5HD2+@`Q"!X`J0">#J;8;@:!&!X&B1*>!J
M@2+@!H`(X`*`*.`!@(C@1!"=Y0N0B>#FG8G@`Q"!X&9AH.%(L)WE`B"!X&H1
M)N`#L(O@"1`!X&JQB^!J$2'@3*"=Y>F-B.`"$('@:2$FX`.@BN`((`+@!B`B
MX`9@BN!0H)WEZ!V!X&B!H.$#,(K@::$HX`&@"N`+((+@::$JX.$M@N`&H(K@
M86$HX`)@!N!I,8/@"&`FX%BPG>4#8(;@%#B?Y520G>7BK8K@`["+X&(AH.$#
MD(G@8;&+X&$1(N`*$"'@"(")X.IMAN`!@(C@YIV(X%R`G>4#@(C@`H"(X&HA
M(N`&("+@`A"+X&`@G>5F8:#A`R""X&HA@N!JH2;@":`JX`J`B.!DH)WEZ1V!
MX`.@BN`&H(K@:6$FX`%@)N#AC8C@!B""X.AM@N!H()WE81&@X0,@@N!I(8+@
M:9$AX`B0*>`)D(K@;*"=Y>:=B>`#H(K@`:"*X&@1(>`&$"'@`2""X.D=@N!P
M()WE9F&@X0,@@N!H(8+@:($FX`F`*.`(@(K@=*"=Y>&-B.`#H(K@!J"*X&EA
M)N`!8";@!B""X.AM@N!X()WE81&@X0,@@N!I(8+@:9$AX`B0*>`)D(K@?*"=
MY>:=B>`#H(K@`:"*X&@1(>`&$"'@`2""X.D=@N"`()WE9F&@X0,@@N!H(8+@
M:($FX`F`*.`(@(K@A*"=Y>&-B.`#H(K@!J"*X&EA)N`!8";@!B""X.AM@N!A
ML:#AB""=Y6D1*^`($"'@`R""X&DA@N`!D(K@:*$KX`:@*N#FG8G@"B""X.FM
M@N"0()WEC!"=Y69AH.$#((+@`Q"!X&@A@N!H@2;@"8`HX`L0@>`($('@ZHV!
MX)00G>6DL)WE`Q"!X`80@>!I82;@"F`FX`8@@N#H;8+@F""=Y6JAH.$#((+@
M:2&"X&F1*N`(D"G@"1"!X)R0G>7F'8'@`Y")X`J0B>!HH2K@!J`JX`H@@N"@
MH)WE9F&@X0,PBN!H,8/@:($FX`&`*.#A+8+@"(")X&&1)N`"D"G@XHV(X`DP
M@^#HG8/@M#6?Y:B@G>5B(:#A`["+X`:PB^`#H(K@86&"X6&ABN`(8`;@81$"
MX`$0AN$+$('@:+&"X>D=@>!I8:#A";`+X&B1`N`)D(OAK+"=Y0J0B>"PH)WE
M`["+X`*PB^`#H(K@:"&&X6BABN`!(`+@:($&X.&=B>`(((+A88&&X0L@@N`)
M@`C@8;$&X`N`B.&TL)WEZ2V"X`.PB^`&L(O@N&"=Y6F1H.$*@(C@`V"&X&&A
MB>$"H`K@86&&X&$1">#BC8C@`1"*X6*AB>$+$('@"*`*X&*Q">`+H(KAO+"=
MY>@=@>`#L(O@";"+X,"0G>5H@:#A!F"*X`.0B>!BH8CA`:`*X&*1B>!B(0C@
MX6V&X`(@BN%AH8CA"R""X`:@"N!AL0C@"Z"*X<2PG>7F+8+@`["+X`BPB^#(
M@)WE9F&@X0F0BN`#@(C@8:&&X0*@"N!A@8C@81$&X.*=B>`!$(KA8J&&X0L0
M@>`)H`K@8K$&X`N@BN',L)WEZ1V!X`.PB^`&L(O@T&"=Y6F1H.$(@(K@`V"&
MX&*AB>$!H`K@8F&&X&(A">#AC8C@`B"*X6&AB>$+((+@"*`*X&&Q">`+H(KA
MU+"=Y>@M@N`#L(O@";"+X-B0G>5H@:#A!F"*X`.0B>!AH8CA`J`*X&&1B>!A
M$0C@XFV&X`$0BN%BH8CA"Q"!X`:@"N!BL0C@"Z"*X=RPG>4)D(K@X*"=Y>8=
M@>`#L(O@9F&@X0BPB^`#H(K@8H&&X6*ABN`!@`C@8B$&X.&=B>`"@(CA82&&
MX0N`B.`)(`+@8;$&X`L@@N'DL)WE"B""X.B@G>7IC8C@`["+X&F1H.$&L(O@
M`Z"*X&%AB>%AH8K@"&`&X&$1">#H+8+@`6"&X6@1B>$+8(;@`A`!X&BQ">`+
M$('A[+"=Y0H0@>#PH)WEXFV&X`.PB^!B(:#A";"+X`.@BN!HD8+A:*&*X`:0
M">!H@0+@Z#*?Y0B0B>'T@)WEYAV!X`N0B>`#@(C@9K&"X0&P"^`"@(C@9B$"
MX`(@B^$*((+@^*"=Y>&=B>`#H(K@81&@X6:ABN!F82'@"6`FX`:`B.#\8)WE
M`+&=Y0-@AN#I+8+@`6"&X&D1(>#BC8C@`A`AX`.PB^!B(:#A`1"*X&FQB^`$
MH9WE:9$BX`B0*>`)8(;@`Z"*X`B1G>7H'8'@`J"*X&@A(N#A;8;@`2`BX`.0
MB>!A$:#A:)&)X&B!(>`&@"C@"("*X`RAG>4"((O@`Z"*X.8M@N`!H(K@9A$A
MX`(0(>`!$(G@$)&=Y>*-B.`#D(G@8B&@X6:1B>!F82+@"&`FX`9@BN`4H9WE
MZ!V!X`.@BN`"H(K@:"$BX`$@(N`"((G@&)&=Y>%MAN`#D(G@81&@X6B1B>!H
M@2'@!H`HX`B`BN`<H9WEYBV"X`.@BN`!H(K@9A$AX`(0(>`!$(G@()&=Y>*-
MB.`#D(G@8B&@X6:1B>!F82+@"&`FX`9@BN`DH9WEZ!V!X`.@BN`"H(K@:"$B
MX`$@(N`"((G@*)&=Y>%MAN`#D(G@81&@X6B1B>!H@2'@!H`HX`B`BN`LH9WE
MYBV"X`.@BN`!H(K@9A$AX`(0(>`!$(G@,)&=Y>*-B.`#D(G@8B&@X6:1B>!F
M82+@"&`FX`9@BN`TH9WEZ!V!X`.@BN`"H(K@:"$BX`$@(N`"((G@.)&=Y>%M
MAN`#D(G@81&@X6B1B>!H@2'@!H`HX.8M@N`(@(K@XHV(X&A1A>`,4(?E/%&=
MY0-0A>`!4(7@9A$AX`(0(>`!$(G@Z!V!X&'!C.`(P(?E0,&=Y6(AH.$#,(S@
M9L$BX`)`A.`.,(/@",`LX&@A(N`!("+@9C&#X`Q0A>#A'87@`C"#X.$]@^!0
M()_E`#"'Y0$`@.`P,)_E`B"/X!!`A^4$`(?E`S"2YP`@D^5$,9WE`B`SX``P
MH.,!```:4]^-XO"/O>BK\__K<&4``"0!``"9>8):H>O9;MR\&X_6P6+*2%H`
M``'*H.,00"WI#,!-X/@/C.5@`*#C)O/_ZP`@H.,,>Y_M-,"?Y300G^4T0)_E
M-."?Y01[@.T(0(#E#."`Y0#`@.4$$(#E&""`Y5P@@.40@+WH`/`@X_#ATL,`
M`````2-%9XFKS>_^W+J8=E0R$`'*H./P1RWI#,!-X.`/C.4"4*#A`("@X10P
MD.6"(:#A`C"3X!@@D.44,(#E7`"0Y0$@@B*E+H+@``!0XP&@H.$8((CE''"(
M`A8```I`0&#B''"(X@4`5.$``(?@!4"@H0$`4.%"```J!#"`X`,`4>$$8($@
M.0``.@H0H.$$(*#A7_/_ZUPPF.4#,(3@0`!3XUPPB.7PA[T8"`"@X=G\_^L&
MH*#A!%!%X#\`5>,;``#:"D"@X5R0B.)`8(KB!`!7X2(``"H)`%3A)```.@:@
MH.$',*#A0."$X@#`E.4$`)3E"!"4Y0P@E.400(3B#@!4X0#`@^4$`(/E"!"#
MY0P@@^40,(/B\___&@@`H.%`4$7BO/S_ZS\`5>-`8(;BYO__R@H`5^$.```Z
M`@``F@4PBN`#`%?A"0``.@4@H.$*$*#A!P"@X2[S_^M<4(CE\(>]Z`:@H.'=
M__^:!@!7X=O__RKP`/#G!3"'X`,`6N'Q__\J^O__Z@1@@>"^__^:!@!0X;S_
M_RKU___J`<J@X_!!+>D,P$W@Z`^,Y7\@X.,4,)'E&&"1Y3-_O^:C,:#A/S`#
MX@'`@^(<@('B.`!<XP%`H.$`4*#A-F^_Y@,@R.<\``#:`!"@XT`@;.(,`(C@
MD/+_ZP0`H.&'_/_K.""@XP`0H.,(`*#ABO+_ZP0`H.'T9<3A@/S_ZP,PU.4$
M`*#A`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4',-3E!##%Y;8P
MU.$%,,7E!#"4Y2,TH.$&,,7E!#"4Y0<PQ>4+,-3E"##%Y;HPU.$),,7E"#"4
MY2,TH.$*,,7E"#"4Y0LPQ>4/,-3E###%Y;XPU.$-,,7E##"4Y2,TH.$.,,7E
M##"4Y0\PQ>43,-3E$##%Y;(QU.$1,,7E$#"4Y2,TH.$2,,7E$#"4Y1,PQ>7P
M0;WHP/+_Z@`0H.,,`(C@."!LXE/R_^O'___J`4`MZ0%`O>@>_R_A/@```$$`
M```,````00```!$```!!````)P```$$````V````00````,```!!````!@``
M`$$````5````00````\```!!````#@```$$````F````00```!,```!!````
M*0```$$````"````00```!D```!!````"@```$$````+````00``````````
M````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-
M4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"
M`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!
M0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@``
M`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M`````#$```!L<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%2
M65]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860``"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````
M,2XP-3D```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-
M10````!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'
M24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'
M24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?
M<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P
M.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R
M7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@
M*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.
M3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@
M*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B
M=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY
M("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R
M;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@
M+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO
M9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I
M;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN
M+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD
M(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M
M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<
M)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A
M<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L
M("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O
M;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S
M(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC
M7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\
M(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-
M04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U
M=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B
M7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B
M7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA
M<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD
M72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L
M(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F
M9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S
M=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?
M;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E
M('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO
M9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE
M.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F
M?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O
M+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H
M)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@
M869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@
M("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T
M7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@
M("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI
M.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF
M="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]
M"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN
M8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`
M861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U
M<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L
M<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H
M)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@
M)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I
M;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P
M87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET[
M"GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R
M96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@
M)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL
M97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R
M(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_
M"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]
M?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R
M968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ
M<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=
M.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B
M1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N
M=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T
M;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*
M?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]
M*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I
M;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K
M("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N
M86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?
M<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E
M="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R
M871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z
M:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E
M<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@
M)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P
M87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY
M("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@
M)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H
M95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S
M:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U
M9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M
M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P
M87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T
M96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*
M)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP
M;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\[
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES
M>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I
M+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[
M(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@
M:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`<&5R;'AS:2YC`````$-!0TA%```^````00````P```!!````$0```$$`
M```G````00```#8```!!`````P```$$````&````00```!4```!!````#P``
M`$$````.````00```"8```!!````$P```$$````I````00````(```!!````
M&0```$$````*````00````L```!!````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#H%P``4!<```$````=`P```0``
M`"@#```=````?`0```P```!X$```#0````!(```9````R)T``!L````$````
M&@```,R=```<````!````/7^_V]P`0``!0````P)```&````7`(```H```":
M!```"P```!`````5``````````,```#`G@```@```.`!```4````$0```!<`
M``"8#@``$0```*@-```2````\````!,````(````'@````@```#[__]O`0``
M"/K__V\0````````````````````````````````````````````````````
M`````-"=`````````````(00``"$$```A!```(00``"$$```A!```(00``"$
M$```A!```(00``"$$```A!```(00``"$$```A!```(00``"$$```A!```(00
M``"$$```A!```(00``"$$```A!```(00``"$$```A!```(00``"$$```A!``
M`(00``"$$```A!```(00``"$$```A!```(00``"$$```A!```(00``"$$```
MA!```(00``"$$```A!```(00``"$$```A!```(00``"$$```A!```(00``"$
M$```A!```(00``"$$```A!```(00``"$$```A!```&@3``````````````!(
M`````````````'@0````````````````````````````````````````````
M`````````````*````I005(N<&T*`````-1+``#H2````````*A)``"L20``
MR$L``/!(``#02P```````+1+``"\2P```````-Q+``!'0T,Z("A!;'!I;F4@
M,3,N,BXQ7V=I=#(P,C,Q,#$T*2`Q,RXR+C$@,C`R,S$P,30`03(```!A96%B
M:0`!*`````4V2UH`!@<(`0D!"@(2!!,!%`$5`1<#&`$:`AP!'@(B`40!`"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M``````L````!`````@```#0!```T`0``&````````````````0`````````3
M````!P````(```!,`0``3`$``"0```````````````0`````````)@```/;_
M_V\"````<`$``'`!``#L````!``````````$````!````#`````+`````@``
M`%P"``!<`@``L`8```4````#````!````!`````X`````P````(````,"0``
M#`D``)H$``````````````$`````````0`````D````"````J`T``*@-``#P
M````!``````````$````"````$D````)````0@```)@.``"8#@``X`$```0`
M```1````!`````@```!2`````0````8```!X$```>!````P`````````````
M``0`````````30````$````&````A!```(00``#D`@`````````````$````
M!````%@````!````!@```&@3``!H$P``F#0`````````````"`````````!>
M`````0````8`````2````$@```P```````````````0`````````9`````$`
M```"````#$@```Q(``#D00`````````````$`````````&P````!`````@``
M`/")``#PB0``!```````````````!`````````!V````#@````,```#(G0``
MR(T```0```````````````0````$````@@````\````#````S)T``,R-```$
M```````````````$````!````(X````&`````P```-"=``#0C0``\`````4`
M````````!`````@```"7`````0````,```#`G@``P(X``$`!````````````
M``0````$````G`````$````#`````*````"0``!$```````````````$````
M`````*(````(`````P```$2@``!$D```+```````````````!`````````"G
M`````0```#``````````1)```#$```````````````$````!````L`````,`
M`'```````````'60```S```````````````!``````````$````#````````
=``````"HD```P````````````````0``````````
